import { LitElement } from 'lit';
type Constructor<T = {}> = new (...args: any[]) => T;
type NativeFormControlElement = HTMLInputElement;
export declare abstract class UUIFormControlMixinInterface<ValueType, DefaultValueType> extends LitElement {
    formAssociated: boolean;
    protected _internals: ElementInternals;
    protected _runValidators(): void;
    get value(): ValueType | DefaultValueType;
    set value(newValue: ValueType | DefaultValueType);
    name: string;
    formResetCallback(): void;
    checkValidity(): boolean;
    get validationMessage(): string;
    get validity(): ValidityState;
    setCustomValidity(error: string): void;
    submit(): void;
    protected abstract getFormElement(): HTMLElement | undefined;
    protected addValidator: (flagKey: FlagTypes, getMessageMethod: () => string, checkMethod: () => boolean) => void;
    protected addFormControlElement(element: NativeFormControlElement): void;
    pristine: boolean;
    required: boolean;
    requiredMessage: string;
    error: boolean;
    errorMessage: string;
}
type FlagTypes = 'badInput' | 'customError' | 'patternMismatch' | 'rangeOverflow' | 'rangeUnderflow' | 'stepMismatch' | 'tooLong' | 'tooShort' | 'typeMismatch' | 'valueMissing' | 'badInput' | 'valid';
/**
 * The mixin allows a custom element to participate in HTML forms.
 *
 * @param {Object} superClass - superclass to be extended.
 * @mixin
 */
export declare const UUIFormControlMixin: <ValueType = FormDataEntryValue | FormData, T extends Constructor<LitElement> = typeof LitElement, DefaultValueType = unknown>(superClass: T, defaultValue: DefaultValueType) => Constructor<UUIFormControlMixinInterface<ValueType, DefaultValueType>> & T;
export {};
